@@ -1,12 +1,15 @@
 import contextvars
 import sys
 import traceback
-from typing import Awaitable, Callable
+from typing import Any, Awaitable, Callable
 
 from fastapi import Request, Response
 from loguru import logger
 
-http_request_context = contextvars.ContextVar("http_request_context", default=None)
+http_request_context = contextvars.ContextVar[dict[str, Any]](
+    "http_request_context", default=None
+)
+cloud_trace_context = contextvars.ContextVar[str]("cloud_trace_context", default=None)
 
 
 async def http_request_middleware_func(
@@ -26,6 +29,9 @@ async def http_request_middleware_func(
     if "user-agent" in request.headers:
         http_request["userAgent"] = request.headers.get("user-agent")
     token = http_request_context.set(http_request)
+
+    if "x-cloud-trace-context" in request.headers:
+        cloud_trace_context.set(request.headers.get("x-cloud-trace-context"))
     try:
         response = await call_next(request)
         logger.info(
